@@ -3,8 +3,6 @@
 //! In particular, there is no root CA, no use of hardware keys / PKCS #11,
 //! no revocation, etc. etc.
 
-use core::convert::TryInto;
-
 use pkcs8::FromPrivateKey as _;
 use rand_core::{OsRng, RngCore};
 
@@ -18,11 +16,7 @@ pub enum Kind {
     X255 = 6,
 }
 
-fn trussed_serialized_key(
-    sensitive: bool,
-    kind: Kind,
-    material: &[u8],
-) -> Vec<u8> {
+fn trussed_serialized_key(sensitive: bool, kind: Kind, material: &[u8]) -> Vec<u8> {
     let mut buffer = Vec::new();
     let mut flags = 0u16;
     // we shouldn't be in the business of injecting "local" keys
